cppcolormap {#mainpage}
===========

**Readme: [github.com/tdegeus/cppcolormap](https://github.com/tdegeus/cppcolormap)**

**Documentation: [cppcolormap.readthedocs.org](https://cppcolormap.readthedocs.org)**

**Doxygen documentation: [tdegeus.github.io/cppcolormap](https://tdegeus.github.io/cppcolormap)**
